@@ -5,12 +5,12 @@ case "$OS" in
   alpine)
     apk update --wait 120
     apk add --wait 120 curl perl bash git
-    curl -s -L -k -o /tmp/rakudo-pkg-Alpine3.7_2019.11-01_x86_64.apk https://github.com/nxadm/rakudo-pkg/releases/download/v2019.11/rakudo-pkg-Alpine3.7_2019.11-01_x86_64.apk
-    apk add --allow-untrusted /tmp/rakudo-pkg-Alpine3.7_2019.11-01_x86_64.apk
+    curl -s -L -k -o /tmp/rakudo-pkg-Alpine3.10_2020.02.1-04_x86_64.apk https://github.com/nxadm/rakudo-pkg/releases/download/v2020.02.1-04/rakudo-pkg-Alpine3.10_2020.02.1-04_x86_64.apk
+    apk add --allow-untrusted /tmp/rakudo-pkg-Alpine3.10_2020.02.1-04_x86_64.apk
 
   ;;
   amazon|centos|red)
-    yum -q -y install make curl perl bash redhat-lsb-core git
+    yum -q -y install make curl perl bash redhat-lsb-core git perl-JSON-PP
     rm -rf /etc/yum.repos.d/rakudo-pkg.repo
     echo -e "[rakudo-pkg]\nname=rakudo-pkg\nbaseurl=https://dl.bintray.com/nxadm/rakudo-pkg-rpms/`lsb_release -is`/`lsb_release -rs| cut -d. -f1`/x86_64\ngpgcheck=0\nenabled=1" | tee -a /etc/yum.repos.d/rakudo-pkg.repo
     yum -q -y install rakudo-pkg
@@ -35,6 +35,12 @@ case "$OS" in
     echo -e "[rakudo-pkg]\nname=rakudo-pkg\nbaseurl=https://dl.bintray.com/nxadm/rakudo-pkg-rpms/`lsb_release -is`/`lsb_release -rs| cut -d. -f1`/x86_64\ngpgcheck=0\nenabled=1" | tee -a /etc/yum.repos.d/rakudo-pkg.repo
     dnf -yq install rakudo-pkg
   ;;
+  opensuse)
+    zypper install -y lsb-release
+    #zypper ar -f https://dl.bintray.com/nxadm/rakudo-pkg-rpms/openSUSE/`lsb-release -rs`/x86_64 rakudo-pkg
+    zypper install -y rakudo-pkg
+    zypper install -y git curl tar gzip
+  ;;
   *)
     printf "Your OS (%s) is not supported\n" "$OS"
     exit 1
